| Title: | The Sparse Online Principal Component Estimation Algorithm |
|---|---|
| Description: | The sparse online principal component can not only process the online data set, but also obtain a sparse solution of the online data set. The philosophy of the package is described in Guo G. (2022) <doi:10.1007/s00180-022-01270-z>. |
| Authors: | Guangbao Guo [aut, cre], Chunjie Wei [aut], Guoqi Qian [aut] |
| Maintainer: | Guangbao Guo <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-06-01 09:48:11 UTC |
| Source: | https://github.com/cran/SOPC |
Heart failure
data("Heart")data("Heart")
A data frame with 299 observations on the following 13 variables.
agea numeric vector
anaemiaa numeric vector
creatinine_phosphokinasea numeric vector
diabetesa numeric vector
ejection_fractiona numeric vector
high_blood_pressurea numeric vector
plateletsa numeric vector
serum_creatininea numeric vector
serum_sodiuma numeric vector
sexa numeric vector
smokinga numeric vector
timea numeric vector
DEATH_EVENTa numeric vector
This dataset contains the medical records of 299 patients who had heart failure, collected during their follow-up period, where each patient profile has 13 clinical features.
The Heart failure data set comes from the UCI database.
Davide Chicco, Giuseppe Jurman. (2020). Machine learning can predict survival of patients with heart failure from serum creatinine and ejection fraction alone. BMC Medical Informatics and Decision Making.
data(Heart) ## maybe str(Heart) ; plot(Heart) ...data(Heart) ## maybe str(Heart) ; plot(Heart) ...
The EMG Physical Action-Hugging data set.
data("Hugging")data("Hugging")
A data frame with 9752 observations on the following 8 variables.
Aa numeric vector
Ba numeric vector
Ca numeric vector
Da numeric vector
Ea numeric vector
Fa numeric vector
Ga numeric vector
Ha numeric vector
The data set is a body movement data set, including 10 normal and 10 aggressive body movements. The data frame with 9752 observations on the following 8 variables.
The Hugging data set comes from the UCI database.
Demir et al. (2019). Surface emg signals and deep transfer learning-based physical action classification. Neural Computing and Applications.
data(Hugging) ## maybe str(Hugging) ; plot(Hugging) ...data(Hugging) ## maybe str(Hugging) ; plot(Hugging) ...
The incremental principal component can handle online data sets with highly correlated.
IPC(data, m, eta)IPC(data, m, eta)
data |
is a highly correlated online data set |
m |
is the number of principal component |
eta |
is the proportion of online data to total data |
Ai,Di
IPC(data=PSA,m=3,eta=0.8)IPC(data=PSA,m=3,eta=0.8)
The online principal component method refers to the IPC method with the best performance among the IPC, the PPC and the SAPC methods.
OPC(data, m, eta)OPC(data, m, eta)
data |
is a highly correlated online data set |
m |
is the number of principal component |
eta |
is the proportion of online data to total data |
Ao,Do
OPC(data=PSA,m=3,eta=0.8)OPC(data=PSA,m=3,eta=0.8)
The traditional principal component method. This method can estimate the eigen space of the data set.
PC(data, m = m)PC(data, m = m)
data |
is a highly correlated data set |
m |
is the number of principal component |
Ahat, Dhat
PC(data=PSA,m=3)PC(data=PSA,m=3)
The perturbation principal component can handle online data sets with highly correlated.
PPC(data, m, eta)PPC(data, m, eta)
data |
is a highly correlated online data set |
m |
is the number of principal component |
eta |
is the proportion of online data to total data |
Ap,Dp
PPC(data=PSA,m=3,eta=0.8)PPC(data=PSA,m=3,eta=0.8)
The prostate specific antigen (PSA) data set.
data("PSA")data("PSA")
lcavola numeric vector
lweighta numeric vector
agea numeric vector
lbpha numeric vector
svia numeric vector
lcpa numeric vector
gleasona numeric vector
pgg45a numeric vector
lpsaa numeric vector
The data set comes from the prostate specific antigen (PSA) data of 96 patients collected by Stanford University Medical Center. These patients all underwent radical prostatectomy.
The Stanford University Medical Center.
NA
data(PSA) ## maybe str(PSA) ; plot(PSA) ...data(PSA) ## maybe str(PSA) ; plot(PSA) ...
The stochastic approximation principal component can handle online data sets with highly correlated.
SAPC(data, m, eta)SAPC(data, m, eta)
data |
is a highly correlated online data set |
m |
is the number of principal component |
eta |
is the proportion of online data to total data |
Asa,Dsa
SAPC(data=PSA,m=3,eta=0.8)SAPC(data=PSA,m=3,eta=0.8)
The sparse online principal component can not only process online data sets, but also obtain a sparse solution of online data sets.
SOPC(data, m, gamma, eta)SOPC(data, m, gamma, eta)
data |
is a highly correlated online data set |
m |
is the number of principal component |
gamma |
is a sparse parameter |
eta |
is the proportion of online data to total data |
Aso,Dso
require(elasticnet) SOPC(PSA,3,0.03,0.6)require(elasticnet) SOPC(PSA,3,0.03,0.6)
The sparse principal component can obtain sparse solutions of the eigenmatrix to better explain the relationship between principal components and original variables.
SPC(data, m, gamma)SPC(data, m, gamma)
data |
is a highly correlated data set |
m |
is the number of principal component |
gamma |
is a sparse parameter |
As,Ds
require(elasticnet) SPC(data=PSA,m=3,gamma=0.03)require(elasticnet) SPC(data=PSA,m=3,gamma=0.03)